@@ -320,6 +320,14 @@ go_string_append_gstring (GString *target, const GString *source)
 	g_string_append_len (target, source->str, source->len);
 }
 
+void
+go_string_append_c_n (GString *target, char c, gsize n)
+{
+	gsize len = target->len;
+	g_string_set_size (target, len + n);
+	memset (target->str + len, c, n);
+}
+
 /* ------------------------------------------------------------------------- */
 
 /**
@@ -699,6 +707,12 @@ go_guess_encoding (const char *raw, size_t len, const char *user_guess,
 		utf8_data = g_convert (raw, len, "UTF-8", guess,
 				       NULL, NULL, &error);
 		if (!error) {
+			/*
+			 * We can actually fail this test when gues is UTF-8,
+			 * see #401588.
+			 */
+			if (!g_utf8_validate (utf8_data, -1, NULL))
+				continue;
 			if (debug)
 				g_print ("Guessed %s as encoding.\n", guess);
 			if (utf8_str)
